@@ -1,10 +1,10 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2022-2023, by Samuel Williams.
+# Copyright, 2022-2024, by Samuel Williams.
 
-require 'net/http'
-require 'uri'
+require "net/http"
+require "uri"
 
 class Dataloader
 	def initialize
