@@ -2,10 +2,10 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2022-2023, by Samuel Williams.
+# Copyright, 2022-2024, by Samuel Williams.
 
-require 'async'
-require_relative 'dataloader'
+require "async"
+require_relative "dataloader"
 
 Async do
 	dataloader = Dataloader.new
