@@ -2,19 +2,19 @@
 
 # Released under the MIT License.
 # Copyright, 2017, by Kent Gruber.
-# Copyright, 2017-2023, by Samuel Williams.
+# Copyright, 2017-2024, by Samuel Williams.
 
-require 'sus/fixtures/async'
-require 'async/condition'
+require "sus/fixtures/async"
+require "async/condition"
 
-require 'a_condition'
+require "async/a_condition"
 
 describe Async::Condition do
 	include Sus::Fixtures::Async::ReactorContext
 	
 	let(:condition) {subject.new}
 	
-	it 'should continue after condition is signalled' do
+	it "should continue after condition is signalled" do
 		task = reactor.async do
 			condition.wait
 		end
@@ -27,7 +27,7 @@ describe Async::Condition do
 		expect(task).to be(:completed?)
 	end
 	
-	it 'can stop nested task' do
+	it "can stop nested task" do
 		producer = nil
 		
 		consumer = reactor.async do |task|
@@ -36,7 +36,7 @@ describe Async::Condition do
 			producer = task.async do |subtask|
 				subtask.yield
 				condition.signal
-				subtask.sleep(10)
+				sleep(10)
 			end
 			
 			condition.wait
@@ -52,5 +52,5 @@ describe Async::Condition do
 		expect(consumer.status).to be == :completed
 	end
 	
-	it_behaves_like ACondition
+	it_behaves_like Async::ACondition
 end
