@@ -1,14 +1,14 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2018-2022, by Samuel Williams.
+# Copyright, 2018-2024, by Samuel Williams.
 
-require 'async'
+require "async"
 
 describe Enumerator do
 	def some_yielder(task)
 		yield 1
-		task.sleep(0.002)
+		sleep(0.002)
 		yield 2
 	end
 	
@@ -56,7 +56,7 @@ describe Enumerator do
 		Async do |task|
 			fiber = Fiber.new do
 				Fiber.yield 1
-				task.sleep(0.002)
+				sleep(0.002)
 				Fiber.yield 2
 			end
 			
@@ -69,4 +69,26 @@ describe Enumerator do
 		expect(result[1]).to be == 2
 		expect(result[2]).to be == nil
 	end
+	
+	it "can stop lazy enumerator" do
+		# This test will hang on older Rubies without the bug fix:
+		skip_unless_minimum_ruby_version("3.3.4")
+		
+		enumerator = Enumerator.new do |yielder|
+			yielder.yield 1
+			sleep
+			yielder.yield 2
+		end
+		
+		Sync do |task|
+			child_task = task.async do
+				enumerator.next
+				enumerator.next
+			end
+			
+			child_task.stop
+			
+			expect(child_task).to be(:stopped?)
+		end
+	end
 end
